@@ -27,6 +27,7 @@
 #[allow(unused_imports)]
 #[macro_use]
 extern crate lightning_encoding_derive as derive;
+#[cfg(feature = "derive")]
 pub use derive::{LightningDecode, LightningEncode};
 
 #[allow(unused_imports)]
@@ -86,7 +87,7 @@ where
         if consumed == data.as_ref().len() {
             Ok(rv)
         } else {
-            Err(Error::DataNotEntirelyConsumed)?
+            Err(Error::DataNotEntirelyConsumed)
         }
     }
 }
